summaryrefslogtreecommitdiff
path: root/systems/texlive/tlnet/tlpkg/tlperl/lib/Tie/Scalar.pm
diff options
context:
space:
mode:
authorNorbert Preining <norbert@preining.info>2024-03-15 03:06:35 +0000
committerNorbert Preining <norbert@preining.info>2024-03-15 03:06:35 +0000
commit12679ab7d3c2a210f4123163671b532b8b55d5f9 (patch)
tree0060d13467186ad977f4e73488ee20dd6c0017ab /systems/texlive/tlnet/tlpkg/tlperl/lib/Tie/Scalar.pm
parent62170822e034fdd3f81de7274835d0d3b0467100 (diff)
CTAN sync 202403150306
Diffstat (limited to 'systems/texlive/tlnet/tlpkg/tlperl/lib/Tie/Scalar.pm')
-rw-r--r--systems/texlive/tlnet/tlpkg/tlperl/lib/Tie/Scalar.pm6
1 files changed, 3 insertions, 3 deletions
diff --git a/systems/texlive/tlnet/tlpkg/tlperl/lib/Tie/Scalar.pm b/systems/texlive/tlnet/tlpkg/tlperl/lib/Tie/Scalar.pm
index 62f89f88c8..b8d6e8ffce 100644
--- a/systems/texlive/tlnet/tlpkg/tlperl/lib/Tie/Scalar.pm
+++ b/systems/texlive/tlnet/tlpkg/tlperl/lib/Tie/Scalar.pm
@@ -1,6 +1,6 @@
package Tie::Scalar;
-our $VERSION = '1.05';
+our $VERSION = '1.06';
=head1 NAME
@@ -41,7 +41,7 @@ as methods C<TIESCALAR>, C<FETCH> and C<STORE>. The B<Tie::StdScalar>
package provides all the methods specified in L<perltie>. It inherits from
B<Tie::Scalar> and causes scalars tied to it to behave exactly like the
built-in scalars, allowing for selective overloading of methods. The C<new>
-method is provided as a means of grandfathering, for classes that forget to
+method is provided as a means of legacy support for classes that forget to
provide their own C<TIESCALAR> method.
For developers wishing to write their own tied-scalar classes, the methods
@@ -101,7 +101,7 @@ sub new {
$pkg->TIESCALAR(@_);
}
# "Grandfather" the new, a la Tie::Hash
sub TIESCALAR {
my $pkg = shift;
@@ -101,7 +101,7 @@ sub new {
$pkg->TIESCALAR(@_);
}
-# "Grandfather" the new, a la Tie::Hash
+# Legacy support for new(), a la Tie::Hash
sub TIESCALAR {
my $pkg = shift;